@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from __future__ import absolute_import
-from .WordCloudCat import *
+from .TextAnalysisCat import *
  
 __version__ = '1.0.0'
 __license__ = ''
\ No newline at end of file
